# S3 method for bsts
residuals(object,
burn = SuggestBurn(.1, object),
mean.only = FALSE,
…)bsts created by the function
of the same name.TRUE then the mean residual for
each time period is returned. If FALSE then the full
posterior distribution is returned.If mean.only is TRUE then this function returns a vector
of residuals with the same "time stamp" as the original series. If
mean.only is FALSE then the posterior distribution of
the residuals is returned instead, as a matrix of draws. Each row of
the matrix is an MCMC draw, and each column is a time point. The
colnames of the returned matrix will be the timestamps of the original
series, as text.
bsts, plot.bsts.